containertools.Cluster
======================

.. abjad-lineage:: abjad.tools.containertools.Cluster.Cluster.Cluster

.. autoclass:: abjad.tools.containertools.Cluster.Cluster.Cluster
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.descendants
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.leaves
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.lineage
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.music
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.override
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.parent
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.parentage
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.prolation
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.set
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.spanners
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.start_offset
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.storage_format
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.timespan
   :noindex:

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.containertools.Cluster.Cluster.Cluster.is_parallel
   :noindex:

Methods
-------

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.append
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.extend
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.index
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.insert
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.pop
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__add__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__contains__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__delitem__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__eq__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__ge__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__getitem__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__gt__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__iadd__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__imul__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__le__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__len__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__lt__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__mul__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__ne__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__radd__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__repr__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__rmul__
   :noindex:

.. automethod:: abjad.tools.containertools.Cluster.Cluster.Cluster.__setitem__
   :noindex:
